@@ -2,7 +2,7 @@ package Net::MitDK;
 
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use Encode qw(encode decode);
 use DateTime;
 use MIME::Entity;
@@ -153,8 +153,6 @@ sub renew_lease
 {
 	my ($self) = @_;
 	my $token = $self->config->{token};
-	return lambda {undef, "expired"}
-		if $token->{dpp}->{expires_on} < time || $token->{ngdp}->{expires_on} < time;
 	return $self->authorization_refresh( $token->{dpp}->{refresh_token}, $token->{ngdp}->{refresh_token});
 }
 
@@ -498,9 +496,11 @@ sub save
 	unless ( -d $home ) {
 		mkdir $home or return (undef, "Cannot create $home: $!");
 		return (undef, "cannot chmod 0750 $home:$!") unless chmod 0750, $home;
-		my ($name,$passwd,$uid,$gid) = getpwnam('nobody');
-		return (undef, "no user `nobody`") unless defined $name;
-		return (undef, "cannot chown user:$name $home:$!") unless chown $>, $gid, $home;
+		if ( $^O !~ /win32/i) {
+			my ($name,$passwd,$uid,$gid) = getpwnam('nobody');
+			return (undef, "no user `nobody`") unless defined $name;
+			return (undef, "cannot chown user:$name $home:$!") unless chown $>, $gid, $home;
+		}
 	}
 
 	my $json;
